==> drools-guvnor-5.0.1-sources.jar: org/drools/guvnor/server/contenthandler/EnumerationContentHandler.java <==
package org.drools.guvnor.server.contenthandler;

/*
 * Copyright 2007 JBoss Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.drools.guvnor.client.rpc.BuilderResult;
import org.drools.guvnor.server.util.DataEnumLoader;
import org.drools.repository.AssetItem;



public class EnumerationContentHandler extends PlainTextContentHandler implements IValidating {

    public BuilderResult[] validateAsset(AssetItem asset) {

        String content = asset.getContent();
        DataEnumLoader loader = new DataEnumLoader(content);
        if (!loader.hasErrors()) {
            return new BuilderResult[0];
        } else {
            List<BuilderResult> errors = new ArrayList<BuilderResult>();
            List errs = loader.getErrors();


            for ( Iterator iter = errs.iterator(); iter.hasNext(); ) {

                BuilderResult result = new BuilderResult();
                result.assetName = asset.getName();
                result.assetFormat = asset.getFormat();
                result.uuid = asset.getUUID();
                result.message = (String) iter.next();
                errors.add( result );
            }

            return errors.toArray( new BuilderResult[errors.size()] );
        }
    }

}

==> drools-guvnor-5.1.1-sources.jar: org/drools/guvnor/server/contenthandler/EnumerationContentHandler.java <==
/**
 * Copyright 2010 JBoss Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.guvnor.server.contenthandler;

/*
 * Copyright 2007 JBoss Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.drools.guvnor.client.rpc.BuilderResult;
import org.drools.guvnor.client.rpc.BuilderResultLine;
import org.drools.ide.common.server.util.DataEnumLoader;
import org.drools.repository.AssetItem;



public class EnumerationContentHandler extends PlainTextContentHandler implements IValidating {

    public BuilderResult validateAsset(AssetItem asset) {

        String content = asset.getContent();
        DataEnumLoader loader = new DataEnumLoader(content);
        if (!loader.hasErrors()) {
            return new BuilderResult();
        } else {
            List<BuilderResultLine> errors = new ArrayList<BuilderResultLine>();
            List errs = loader.getErrors();


            for ( Iterator iter = errs.iterator(); iter.hasNext(); ) {

                BuilderResultLine result = new BuilderResultLine();
                result.assetName = asset.getName();
                result.assetFormat = asset.getFormat();
                result.uuid = asset.getUUID();
                result.message = (String) iter.next();
                errors.add( result );
            }


            BuilderResult result = new BuilderResult();
            result.lines = errors.toArray( new BuilderResultLine[errors.size()] );
            
            return result;
        }
    }

}
